@@ -248,7 +248,8 @@ class BaseDBoard(object):
         
         if not isinstance(workspace, BaseWorkspace):
             workspace = self.workspaces.getByPAR(workspace)
-        
+        if workspace is None:
+            raise ValueError('Undefined workspace!')
         if self.dmode == DBoardPreferedDapiMode.COMMAND:
             if workspace.standby:
                 self.dapi.cmd.standby()
